EXPORTS
	??0CDirectGdiContext@@AAE@AAVCDirectGdiDriver@@@Z @ 1  NONAME ; CDirectGdiContext::CDirectGdiContext(class CDirectGdiDriver &)
	??0CDirectGdiFont@@QAE@XZ @ 2  NONAME ; CDirectGdiFont::CDirectGdiFont(void)
	??0RDirectGdiDrawableSource@@QAE@AAVCDirectGdiDriver@@@Z @ 3  NONAME ; RDirectGdiDrawableSource::RDirectGdiDrawableSource(class CDirectGdiDriver &)
	??0RDirectGdiImageTarget@@QAE@AAVCDirectGdiDriver@@@Z @ 4  NONAME ; RDirectGdiImageTarget::RDirectGdiImageTarget(class CDirectGdiDriver &)
	??1CDirectGdiContext@@UAE@XZ @ 5  NONAME ; CDirectGdiContext::~CDirectGdiContext(void)
	??1CDirectGdiFont@@UAE@XZ @ 6  NONAME ; CDirectGdiFont::~CDirectGdiFont(void)
	??4CDirectGdiFont@@QAEXABV0@@Z @ 7  NONAME ; void CDirectGdiFont::operator=(class CDirectGdiFont const &)
	?Activate@CDirectGdiContext@@QAEHAAVRDirectGdiImageTarget@@@Z @ 8  NONAME ; int CDirectGdiContext::Activate(class RDirectGdiImageTarget &)
	?Address@CDirectGdiFont@@QBEPAVCBitmapFont@@XZ @ 9  NONAME ; class CBitmapFont * CDirectGdiFont::Address(void) const
	?BitBlt@CDirectGdiContext@@QAEXABVTPoint@@ABVCFbsBitmap@@@Z @ 10  NONAME ; void CDirectGdiContext::BitBlt(class TPoint const &, class CFbsBitmap const &)
	?BitBlt@CDirectGdiContext@@QAEXABVTPoint@@ABVCFbsBitmap@@ABVTRect@@@Z @ 11  NONAME ; void CDirectGdiContext::BitBlt(class TPoint const &, class CFbsBitmap const &, class TRect const &)
	?BitBltMasked@CDirectGdiContext@@QAEXABVTPoint@@ABVCFbsBitmap@@ABVTRect@@10@Z @ 12  NONAME ; void CDirectGdiContext::BitBltMasked(class TPoint const &, class CFbsBitmap const &, class TRect const &, class CFbsBitmap const &, class TPoint const &)
	?BitBltMasked@CDirectGdiContext@@QAEXABVTPoint@@ABVCFbsBitmap@@ABVTRect@@1H@Z @ 13  NONAME ; void CDirectGdiContext::BitBltMasked(class TPoint const &, class CFbsBitmap const &, class TRect const &, class CFbsBitmap const &, int)
	?BrushColor@CDirectGdiContext@@QBE?AVTRgb@@XZ @ 14  NONAME ; class TRgb CDirectGdiContext::BrushColor(void) const
	?Clear@CDirectGdiContext@@QAEXABVTRect@@@Z @ 15  NONAME ; void CDirectGdiContext::Clear(class TRect const &)
	?Clear@CDirectGdiContext@@QAEXXZ @ 16  NONAME ; void CDirectGdiContext::Clear(void)
	?Close@CDirectGdiDriver@@QAEXXZ @ 17  NONAME ; void CDirectGdiDriver::Close(void)
	?Close@RDirectGdiDrawableSource@@QAEXXZ @ 18  NONAME ; void RDirectGdiDrawableSource::Close(void)
	?Close@RDirectGdiImageTarget@@QAEXXZ @ 19  NONAME ; void RDirectGdiImageTarget::Close(void)
	?CopyRect@CDirectGdiContext@@QAEXABVTPoint@@ABVTRect@@@Z @ 20  NONAME ; void CDirectGdiContext::CopyRect(class TPoint const &, class TRect const &)
	?CopySettings@CDirectGdiContext@@QAEXABV1@@Z @ 21  NONAME ; void CDirectGdiContext::CopySettings(class CDirectGdiContext const &)
	?Create@RDirectGdiDrawableSource@@QAEHABVRSgDrawable@@@Z @ 22  NONAME ; int RDirectGdiDrawableSource::Create(class RSgDrawable const &)
	?Create@RDirectGdiImageTarget@@QAEHABVRSgImage@@@Z @ 23  NONAME ; int RDirectGdiImageTarget::Create(class RSgImage const &)
	?DrawArc@CDirectGdiContext@@QAEXABVTRect@@ABVTPoint@@1@Z @ 24  NONAME ; void CDirectGdiContext::DrawArc(class TRect const &, class TPoint const &, class TPoint const &)
	?DrawBitmap@CDirectGdiContext@@QAEXABVTRect@@ABVCFbsBitmap@@0@Z @ 25  NONAME ; void CDirectGdiContext::DrawBitmap(class TRect const &, class CFbsBitmap const &, class TRect const &)
	?DrawBitmap@CDirectGdiContext@@QAEXABVTRect@@ABVCFbsBitmap@@@Z @ 26  NONAME ; void CDirectGdiContext::DrawBitmap(class TRect const &, class CFbsBitmap const &)
	?DrawBitmapMasked@CDirectGdiContext@@QAEXABVTRect@@ABVCFbsBitmap@@01H@Z @ 27  NONAME ; void CDirectGdiContext::DrawBitmapMasked(class TRect const &, class CFbsBitmap const &, class TRect const &, class CFbsBitmap const &, int)
	?DrawEllipse@CDirectGdiContext@@QAEXABVTRect@@@Z @ 28  NONAME ; void CDirectGdiContext::DrawEllipse(class TRect const &)
	?DrawLine@CDirectGdiContext@@QAEXABVTPoint@@0@Z @ 29  NONAME ; void CDirectGdiContext::DrawLine(class TPoint const &, class TPoint const &)
	?DrawLineBy@CDirectGdiContext@@QAEXABVTPoint@@@Z @ 30  NONAME ; void CDirectGdiContext::DrawLineBy(class TPoint const &)
	?DrawLineTo@CDirectGdiContext@@QAEXABVTPoint@@@Z @ 31  NONAME ; void CDirectGdiContext::DrawLineTo(class TPoint const &)
	?DrawPie@CDirectGdiContext@@QAEXABVTRect@@ABVTPoint@@1@Z @ 32  NONAME ; void CDirectGdiContext::DrawPie(class TRect const &, class TPoint const &, class TPoint const &)
	?DrawPolyLine@CDirectGdiContext@@QAEXABV?$TArray@VTPoint@@@@@Z @ 33  NONAME ; void CDirectGdiContext::DrawPolyLine(class TArray<class TPoint> const &)
	?DrawPolyLineNoEndPoint@CDirectGdiContext@@QAEXABV?$TArray@VTPoint@@@@@Z @ 34  NONAME ; void CDirectGdiContext::DrawPolyLineNoEndPoint(class TArray<class TPoint> const &)
	?DrawPolygon@CDirectGdiContext@@QAEXABV?$TArray@VTPoint@@@@W4TFillRule@DirectGdi@@@Z @ 35  NONAME ; void CDirectGdiContext::DrawPolygon(class TArray<class TPoint> const &, enum DirectGdi::TFillRule)
	?DrawRect@CDirectGdiContext@@QAEXABVTRect@@@Z @ 36  NONAME ; void CDirectGdiContext::DrawRect(class TRect const &)
	?DrawResource@CDirectGdiContext@@QAEXABVTPoint@@ABVRDirectGdiDrawableSource@@W4TGraphicsRotation@DirectGdi@@@Z @ 37  NONAME ; void CDirectGdiContext::DrawResource(class TPoint const &, class RDirectGdiDrawableSource const &, enum DirectGdi::TGraphicsRotation)
	?DrawResource@CDirectGdiContext@@QAEXABVTRect@@ABVRDirectGdiDrawableSource@@0W4TGraphicsRotation@DirectGdi@@@Z @ 38  NONAME ; void CDirectGdiContext::DrawResource(class TRect const &, class RDirectGdiDrawableSource const &, class TRect const &, enum DirectGdi::TGraphicsRotation)
	?DrawResource@CDirectGdiContext@@QAEXABVTRect@@ABVRDirectGdiDrawableSource@@ABVTDesC8@@@Z @ 39  NONAME ; void CDirectGdiContext::DrawResource(class TRect const &, class RDirectGdiDrawableSource const &, class TDesC8 const &)
	?DrawResource@CDirectGdiContext@@QAEXABVTRect@@ABVRDirectGdiDrawableSource@@W4TGraphicsRotation@DirectGdi@@@Z @ 40  NONAME ; void CDirectGdiContext::DrawResource(class TRect const &, class RDirectGdiDrawableSource const &, enum DirectGdi::TGraphicsRotation)
	?DrawRoundRect@CDirectGdiContext@@QAEXABVTRect@@ABVTSize@@@Z @ 41  NONAME ; void CDirectGdiContext::DrawRoundRect(class TRect const &, class TSize const &)
	?DrawText@CDirectGdiContext@@QAEXABVTDesC16@@PBVTTextParameters@DirectGdi@@@Z @ 42  NONAME ; void CDirectGdiContext::DrawText(class TDesC16 const &, class DirectGdi::TTextParameters const *)
	?DrawText@CDirectGdiContext@@QAEXABVTDesC16@@PBVTTextParameters@DirectGdi@@ABVTPoint@@@Z @ 43  NONAME ; void CDirectGdiContext::DrawText(class TDesC16 const &, class DirectGdi::TTextParameters const *, class TPoint const &)
	?DrawText@CDirectGdiContext@@QAEXABVTDesC16@@PBVTTextParameters@DirectGdi@@ABVTRect@@@Z @ 44  NONAME ; void CDirectGdiContext::DrawText(class TDesC16 const &, class DirectGdi::TTextParameters const *, class TRect const &)
	?DrawText@CDirectGdiContext@@QAEXABVTDesC16@@PBVTTextParameters@DirectGdi@@ABVTRect@@HW4TTextAlign@4@H@Z @ 45  NONAME ; void CDirectGdiContext::DrawText(class TDesC16 const &, class DirectGdi::TTextParameters const *, class TRect const &, int, enum DirectGdi::TTextAlign, int)
	?DrawTextVertical@CDirectGdiContext@@QAEXABVTDesC16@@PBVTTextParameters@DirectGdi@@ABVTPoint@@H@Z @ 46  NONAME ; void CDirectGdiContext::DrawTextVertical(class TDesC16 const &, class DirectGdi::TTextParameters const *, class TPoint const &, int)
	?DrawTextVertical@CDirectGdiContext@@QAEXABVTDesC16@@PBVTTextParameters@DirectGdi@@ABVTRect@@H@Z @ 47  NONAME ; void CDirectGdiContext::DrawTextVertical(class TDesC16 const &, class DirectGdi::TTextParameters const *, class TRect const &, int)
	?DrawTextVertical@CDirectGdiContext@@QAEXABVTDesC16@@PBVTTextParameters@DirectGdi@@ABVTRect@@HHHW4TTextAlign@4@H@Z @ 48  NONAME ; void CDirectGdiContext::DrawTextVertical(class TDesC16 const &, class DirectGdi::TTextParameters const *, class TRect const &, int, int, int, enum DirectGdi::TTextAlign, int)
	?DrawTextVertical@CDirectGdiContext@@QAEXABVTDesC16@@PBVTTextParameters@DirectGdi@@ABVTRect@@HHW4TTextAlign@4@H@Z @ 49  NONAME ; void CDirectGdiContext::DrawTextVertical(class TDesC16 const &, class DirectGdi::TTextParameters const *, class TRect const &, int, int, enum DirectGdi::TTextAlign, int)
	?DrawTextVertical@CDirectGdiContext@@QAEXABVTDesC16@@PBVTTextParameters@DirectGdi@@H@Z @ 50  NONAME ; void CDirectGdiContext::DrawTextVertical(class TDesC16 const &, class DirectGdi::TTextParameters const *, int)
	?Duplicate@CDirectGdiFont@@QAEHH@Z @ 51  NONAME ; int CDirectGdiFont::Duplicate(int)
	?ExternalizeL@CDirectGdiContext@@QAEXAAVRWriteStream@@@Z @ 52  NONAME ; void CDirectGdiContext::ExternalizeL(class RWriteStream &)
	?Finish@CDirectGdiDriver@@QAEXXZ @ 53  NONAME ; void CDirectGdiDriver::Finish(void)
	?Flush@CDirectGdiDriver@@QAEXXZ @ 54  NONAME ; void CDirectGdiDriver::Flush(void)
	?GetError@CDirectGdiDriver@@QAEHXZ @ 55  NONAME ; int CDirectGdiDriver::GetError(void)
	?GetInterface@CDirectGdiContext@@QAEHVTUid@@AAPAX@Z @ 56  NONAME ; int CDirectGdiContext::GetInterface(class TUid, void * &)
	?HasBrushPattern@CDirectGdiContext@@QBEHXZ @ 57  NONAME ; int CDirectGdiContext::HasBrushPattern(void) const
	?HasFont@CDirectGdiContext@@QBEHXZ @ 58  NONAME ; int CDirectGdiContext::HasFont(void) const
	?InternalizeL@CDirectGdiContext@@QAEXAAVRReadStream@@@Z @ 59  NONAME ; void CDirectGdiContext::InternalizeL(class RReadStream &)
	?MoveBy@CDirectGdiContext@@QAEXABVTPoint@@@Z @ 60  NONAME ; void CDirectGdiContext::MoveBy(class TPoint const &)
	?MoveTo@CDirectGdiContext@@QAEXABVTPoint@@@Z @ 61  NONAME ; void CDirectGdiContext::MoveTo(class TPoint const &)
	?NewL@CDirectGdiContext@@SAPAV1@AAVCDirectGdiDriver@@@Z @ 62  NONAME ; class CDirectGdiContext * CDirectGdiContext::NewL(class CDirectGdiDriver &)
	?NoJustifyAutoUpdate@CDirectGdiContext@@QAEXXZ @ 63  NONAME ; void CDirectGdiContext::NoJustifyAutoUpdate(void)
	?Open@CDirectGdiDriver@@SAHXZ @ 64  NONAME ; int CDirectGdiDriver::Open(void)
	?PenColor@CDirectGdiContext@@QBE?AVTRgb@@XZ @ 65  NONAME ; class TRgb CDirectGdiContext::PenColor(void) const
	?Plot@CDirectGdiContext@@QAEXABVTPoint@@@Z @ 66  NONAME ; void CDirectGdiContext::Plot(class TPoint const &)
	?Reset@CDirectGdiContext@@QAEXXZ @ 67  NONAME ; void CDirectGdiContext::Reset(void)
	?Reset@CDirectGdiFont@@QAEXXZ @ 68  NONAME ; void CDirectGdiFont::Reset(void)
	?ResetBrushPattern@CDirectGdiContext@@QAEXXZ @ 69  NONAME ; void CDirectGdiContext::ResetBrushPattern(void)
	?ResetClippingRegion@CDirectGdiContext@@QAEXXZ @ 70  NONAME ; void CDirectGdiContext::ResetClippingRegion(void)
	?ResetFont@CDirectGdiContext@@QAEXXZ @ 71  NONAME ; void CDirectGdiContext::ResetFont(void)
	?SetBrushColor@CDirectGdiContext@@QAEXABVTRgb@@@Z @ 72  NONAME ; void CDirectGdiContext::SetBrushColor(class TRgb const &)
	?SetBrushOrigin@CDirectGdiContext@@QAEXABVTPoint@@@Z @ 73  NONAME ; void CDirectGdiContext::SetBrushOrigin(class TPoint const &)
	?SetBrushPattern@CDirectGdiContext@@QAEXABVCFbsBitmap@@@Z @ 74  NONAME ; void CDirectGdiContext::SetBrushPattern(class CFbsBitmap const &)
	?SetBrushPattern@CDirectGdiContext@@QAEXH@Z @ 75  NONAME ; void CDirectGdiContext::SetBrushPattern(int)
	?SetBrushStyle@CDirectGdiContext@@QAEXW4TBrushStyle@DirectGdi@@@Z @ 76  NONAME ; void CDirectGdiContext::SetBrushStyle(enum DirectGdi::TBrushStyle)
	?SetCharJustification@CDirectGdiContext@@QAEXHH@Z @ 77  NONAME ; void CDirectGdiContext::SetCharJustification(int, int)
	?SetClippingRegion@CDirectGdiContext@@QAEXABVTRegion@@@Z @ 78  NONAME ; void CDirectGdiContext::SetClippingRegion(class TRegion const &)
	?SetDrawMode@CDirectGdiContext@@QAEXW4TDrawMode@DirectGdi@@@Z @ 79  NONAME ; void CDirectGdiContext::SetDrawMode(enum DirectGdi::TDrawMode)
	?SetError@CDirectGdiDriver@@AAEXH@Z @ 80  NONAME ; void CDirectGdiDriver::SetError(int)
	?SetFont@CDirectGdiContext@@QAEXPBVCFont@@@Z @ 81  NONAME ; void CDirectGdiContext::SetFont(class CFont const *)
	?SetFontNoDuplicate@CDirectGdiContext@@QAEXPBVCDirectGdiFont@@@Z @ 82  NONAME ; void CDirectGdiContext::SetFontNoDuplicate(class CDirectGdiFont const *)
	?SetJustifyAutoUpdate@CDirectGdiContext@@QAEXXZ @ 83  NONAME ; void CDirectGdiContext::SetJustifyAutoUpdate(void)
	?SetOrigin@CDirectGdiContext@@QAEXABVTPoint@@@Z @ 84  NONAME ; void CDirectGdiContext::SetOrigin(class TPoint const &)
	?SetPenColor@CDirectGdiContext@@QAEXABVTRgb@@@Z @ 85  NONAME ; void CDirectGdiContext::SetPenColor(class TRgb const &)
	?SetPenSize@CDirectGdiContext@@QAEXABVTSize@@@Z @ 86  NONAME ; void CDirectGdiContext::SetPenSize(class TSize const &)
	?SetPenStyle@CDirectGdiContext@@QAEXW4TPenStyle@DirectGdi@@@Z @ 87  NONAME ; void CDirectGdiContext::SetPenStyle(enum DirectGdi::TPenStyle)
	?SetStrikethroughStyle@CDirectGdiContext@@QAEXW4TFontStrikethrough@DirectGdi@@@Z @ 88  NONAME ; void CDirectGdiContext::SetStrikethroughStyle(enum DirectGdi::TFontStrikethrough)
	?SetTextShadowColor@CDirectGdiContext@@QAEXABVTRgb@@@Z @ 89  NONAME ; void CDirectGdiContext::SetTextShadowColor(class TRgb const &)
	?SetUnderlineStyle@CDirectGdiContext@@QAEXW4TFontUnderline@DirectGdi@@@Z @ 90  NONAME ; void CDirectGdiContext::SetUnderlineStyle(enum DirectGdi::TFontUnderline)
	?SetWordJustification@CDirectGdiContext@@QAEXHH@Z @ 91  NONAME ; void CDirectGdiContext::SetWordJustification(int, int)
	?Static@CDirectGdiDriver@@SAPAV1@XZ @ 92  NONAME ; class CDirectGdiDriver * CDirectGdiDriver::Static(void)
	?TextShadowColor@CDirectGdiContext@@QBE?AVTRgb@@XZ @ 93  NONAME ; class TRgb CDirectGdiContext::TextShadowColor(void) const
	?UpdateJustification@CDirectGdiContext@@QAEXABVTDesC16@@PBVTTextParameters@DirectGdi@@@Z @ 94  NONAME ; void CDirectGdiContext::UpdateJustification(class TDesC16 const &, class DirectGdi::TTextParameters const *)
	?UpdateJustificationVertical@CDirectGdiContext@@QAEXABVTDesC16@@PBVTTextParameters@DirectGdi@@H@Z @ 95  NONAME ; void CDirectGdiContext::UpdateJustificationVertical(class TDesC16 const &, class DirectGdi::TTextParameters const *, int)
	?GetInterface@CDirectGdiDriver@@QAEHVTUid@@AAPAX@Z @ 96 NONAME ; int CDirectGdiDriver::GetInterface(class TUid, void * &)
	??0RDirectGdiDrawableSource@@QAE@XZ @ 97 NONAME ; RDirectGdiDrawableSource::RDirectGdiDrawableSource(void)
	??0RDirectGdiImageTarget@@QAE@XZ @ 98 NONAME ; RDirectGdiImageTarget::RDirectGdiImageTarget(void)

